From ad0a1c2bea80d4814ae91cf354dd5923d0d84add Mon Sep 17 00:00:00 2001
From: Ramakrishnan Muthukrishnan <ram@leastauthority.com>
Date: Fri, 25 Feb 2022 18:31:12 +0530
Subject: [PATCH] rigctl: act on PTT via CAT only if VOX is disabled

If vox is ON and PTT is sent via CAT, the PTT cat command would be
ignored.
---
 rigctl.c | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/rigctl.c b/rigctl.c
index 72d45e1..7a12457 100644
--- a/rigctl.c
+++ b/rigctl.c
@@ -3924,9 +3924,11 @@ int parse_cmd(void *data) {
       implemented = FALSE;
       break;
     case 'X': // TX
       // set transceiver to TX mode
       if (command[2] == ';') {
-        mox_update(1);
+          if (vox_enabled == 0) {
+              mox_update(1);
+          }
       }
       break;
     case 'Y': // TY
@@ -3924,9 +3924,11 @@ int parse_cmd(void *data) {
       break;
     case 'X': // TX
-      // set transceiver to TX mode
+      // set transceiver to TX mode if VOX is not enabled
       if (command[2] == ';') {
-- 
2.45.2